/**
 * Copyright (c) 2014 - 2018, Nordic Semiconductor ASA
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form, except as embedded into a Nordic
 *    Semiconductor ASA integrated circuit in a product or a software update for
 *    such product, must reproduce the above copyright notice, this list of
 *    conditions and the following disclaimer in the documentation and/or other
 *    materials provided with the distribution.
 * 
 * 3. Neither the name of Nordic Semiconductor ASA nor the names of its
 *    contributors may be used to endorse or promote products derived from this
 *    software without specific prior written permission.
 * 
 * 4. This software, with or without modification, must only be used with a
 *    Nordic Semiconductor ASA integrated circuit.
 * 
 * 5. Any software provided in binary form under this license must not be reverse
 *    engineered, decompiled, modified and/or disassembled.
 * 
 * THIS SOFTWARE IS PROVIDED BY NORDIC SEMICONDUCTOR ASA "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL NORDIC SEMICONDUCTOR ASA OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
 
#ifndef REG_SERVICE_H__
#define REG_SERVICE_H__

#include <stdint.h>
#include "ble.h"
#include "ble_srv_common.h"
#include "rtc_wakeup.h"

#define BLE_UUID_REGISTR_BASE_UUID    {0x93, 0x3D, 0x87, 0xBD, 0x63, 0xD6, 0x14, 0xAB, 0xE9, 0x11, 0xB6, 0x15, 0x00, 0x00, 0x00, 0x00} // 128-bit base UUID

#define BLE_UUID_REGISTR_SERVICE       0xFACE // Just a random, but recognizable value
#define BLE_UUID_REGISTR_WRITE_UUID    0xDAFF
#define BLE_UUID_REGISTR_READ_UUID     0xEEFF

extern uint8_t pass;    
extern uint8_t disc_client;
extern bool action_evt;
//extern uint8_t hadle_client;
   
/**
 * @brief This structure contains various status information for our service. 
 * It only holds one entry now, but will be populated with more items as we go.
 * The name is based on the naming convention used in Nordic's SDKs. 
 * 'ble indicates that it is a Bluetooth Low Energy relevant structure and 
 * os is short for Our Service). 
 */
typedef struct
{
    uint16_t                    service_handle;/**< Handle of Our Service (as provided by the BLE stack). */
    
    uint16_t                    conn_handle;//Add handles for the characteristic to struct
    ble_gatts_char_handles_t    char_handles;
    
}ble_reg_serv_t;



void get_cccd_reg_serv(ble_reg_serv_t * p_our_service);
void reg_service_init(ble_reg_serv_t * p_reg_service);
void ble_registration_service_on_ble_evt(ble_evt_t const * p_ble_evt, void * p_context);
void send_synchro_param(ble_reg_serv_t *p_reg_service, uint8_t *parametrs);
//void status_accept_password(ble_reg_serv_t *p_reg_service, uint16_t *status);

#endif  /* _ OUR_SERVICE_H__ */
